<?php
// admin/components.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

// PHP Function for content preview with variable replacement
function previewContent($content, $siteTitle = 'Example Site', $menuHtml = '') {
    $replacements = [
        '{site_title}' => $siteTitle,
        '{site_name}' => $siteTitle,
        '{site_url}' => 'example.com', // Добавляем переменную для URL
        '{menu}' => $menuHtml,
        '{navigation}' => $menuHtml,
        '{current_year}' => date('Y')
    ];
    return str_replace(array_keys($replacements), array_values($replacements), $content);
}

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager
    $authManager = new AuthManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Получаем site_id из GET-параметра
    $siteId = isset($_GET['site_id']) ? (int)$_GET['site_id'] : null;
    $site = null;

    // Если site_id указан, получаем информацию о сайте
    if ($siteId) {
        $siteStmt = $db->prepare("SELECT id, domain, title FROM sites WHERE id = ?");
        $siteStmt->execute([$siteId]);
        $site = $siteStmt->fetch(PDO::FETCH_ASSOC);

        if (!$site) {
            $_SESSION['notification'] = [
                'type' => 'danger',
                'message' => 'Site not found'
            ];
            header('Location: sites.php');
            exit;
        }
    }
// Модифицируйте условие проверки siteId
if (!$siteId) {
    // Создаем глобальный компонент (не привязанный к сайту)
    $siteId = null;
    $site = ['domain' => 'Global', 'title' => 'Global Components'];
} else {
    // Получаем информацию о сайте
    $siteStmt = $db->prepare("SELECT id, domain, title FROM sites WHERE id = :id");
    $siteStmt->bindValue(':id', $siteId, PDO::PARAM_INT);
    $siteStmt->execute();
    $site = $siteStmt->fetch(PDO::FETCH_ASSOC);
}
    // Получаем фильтр по типу компонента
    $componentType = isset($_GET['type']) ? $_GET['type'] : null;
    $validTypes = ['header', 'footer', 'sidebar'];
    if ($componentType && !in_array($componentType, $validTypes)) {
        $componentType = null;
    }

    // Настраиваем пагинацию
    $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
    $perPage = 15;
    $offset = ($page - 1) * $perPage;

    // Получаем список компонентов (для конкретного сайта или для всех сайтов)
    $components = [];
    $totalComponents = 0;

    // Строим условие WHERE
    $whereConditions = [];
    $whereSql = "";
    $countParams = [];
    $queryParams = [];

    if ($siteId !== null) {
        $whereConditions[] = "c.site_id = :site_id";
        $countParams[':site_id'] = $siteId;
        $queryParams[':site_id'] = $siteId;
    }

    if ($componentType) {
        $whereConditions[] = "c.type = :component_type";
        $countParams[':component_type'] = $componentType;
        $queryParams[':component_type'] = $componentType;
    }

    if (!empty($whereConditions)) {
        $whereSql = "WHERE " . implode(" AND ", $whereConditions);
    }

    // Получаем общее количество компонентов
    $countSql = "SELECT COUNT(*) FROM components c {$whereSql}";
    $countStmt = $db->prepare($countSql);
    $countStmt->execute($countParams);
    $totalComponents = $countStmt->fetchColumn();
    $totalPages = ceil($totalComponents / $perPage);

    // Получаем компоненты с именованными параметрами для пагинации
    $sql = "
        SELECT c.*, s.domain 
        FROM components c 
        JOIN sites s ON c.site_id = s.id 
        {$whereSql}
        ORDER BY c.type, c.created_at DESC 
        LIMIT :offset, :per_page
    ";
    
    $componentStmt = $db->prepare($sql);
    
    // Добавляем параметры для LIMIT
    $queryParams[':offset'] = $offset;
    $queryParams[':per_page'] = $perPage;
    
    // Связываем все параметры
    foreach ($queryParams as $key => $value) {
        $paramType = is_int($value) ? PDO::PARAM_INT : PDO::PARAM_STR;
        $componentStmt->bindValue($key, $value, $paramType);
    }
    
    $componentStmt->execute();
    $components = $componentStmt->fetchAll(PDO::FETCH_ASSOC);

    // Обработка уведомлений
    $notification = null;
    if (isset($_SESSION['notification'])) {
        $notification = $_SESSION['notification'];
        unset($_SESSION['notification']);
    }

    $pageTitle = $site ? 'Components - ' . htmlspecialchars($site['domain']) : 'All Components';

} catch (Exception $e) {
    error_log("Components list error: " . $e->getMessage());
    $error = "System error: " . $e->getMessage();
}


?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <!-- Bootstrap CSS (from CDN) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome (from CDN) -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- jQuery -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
        .pagination {
            justify-content: center;
        }
        .component-preview {
            max-height: 100px;
            overflow: hidden;
            position: relative;
        }
        .component-preview::after {
            content: "";
            position: absolute;
            bottom: 0;
            left: 0;
            right: 0;
            height: 30px;
            background: linear-gradient(to bottom, rgba(255,255,255,0), rgba(255,255,255,1));
        }
        .badge-header {
            background-color: #3498db;
        }
        .badge-footer {
            background-color: #2ecc71;
        }
        .badge-sidebar {
            background-color: #9b59b6;
        }
        .component-type-filter {
            display: flex;
            gap: 10px;
            margin-bottom: 20px;
        }
        .component-type-filter .btn {
            flex: 1;
        }
        .bg-header { background-color: #3498db !important; }
        .bg-footer { background-color: #2ecc71 !important; }
        .bg-sidebar { background-color: #9b59b6 !important; }
        
.btn-group .btn-sm {
    padding: 0.25rem 0.5rem;
}
.btn-group .btn-sm i {
    display: inline-block;
    font-size: 0.875rem;
}
.actions .btn {
    margin-right: 3px;
    display: inline-flex;
    align-items: center;
    justify-content: center;
    min-width: 2rem;
}

/* Preview Modal Styles */
.preview-modal {
    display: none;
    position: fixed;
    z-index: 1050;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    overflow: auto;
    background-color: rgba(0,0,0,0.4);
}

.preview-modal .modal-content {
    background-color: #fefefe;
    margin: 5% auto;
    padding: 0;
    border: 1px solid #888;
    width: 90%;
    max-width: 1200px;
    height: 80%;
    position: relative;
    border-radius: 6px;
    box-shadow: 0 4px 8px rgba(0,0,0,0.1);
}

.preview-control-bar {
    position: absolute;
    top: -40px;
    right: 0;
    display: flex;
    gap: 10px;
    padding: 5px;
    background-color: rgba(0,0,0,0.6);
    border-radius: 4px;
    z-index: 1060;
}

.preview-control-bar button {
    background: transparent;
    border: none;
    color: white;
    font-size: 14px;
    cursor: pointer;
    display: flex;
    align-items: center;
    gap: 5px;
    padding: 5px 10px;
    border-radius: 3px;
}

.preview-control-bar button:hover {
    background-color: rgba(255,255,255,0.1);
}

.preview-control-bar button.active {
    background-color: rgba(255,255,255,0.2);
}

.preview-device-selector {
    display: flex;
    gap: 5px;
}

.preview-modal .close {
    position: absolute;
    right: 15px;
    top: 10px;
    color: #aaa;
    font-size: 28px;
    font-weight: bold;
    z-index: 1;
    cursor: pointer;
}

.preview-modal .close:hover,
.preview-modal .close:focus {
    color: #000;
    text-decoration: none;
    cursor: pointer;
}

#previewFrame {
    width: 100%;
    height: 100%;
    border: none;
    border-radius: 6px;
}
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="/pbns2/admin/">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="/pbns2/admin/">
                            <i class="fas fa-tachometer-alt"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sites.php">
                            <i class="fas fa-globe"></i> Sites
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="pages.php">
                            <i class="fas fa-file-alt"></i> Pages
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="components.php">
                            <i class="fas fa-puzzle-piece"></i> Components
                        </a>
                    </li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user-cog"></i> Profile
                                </a>
                            </li>
                            <li><hr class="dropdown-divider"></li>
                            <li>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt"></i> Logout
                                </a>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    
    <div class="container-fluid mt-4">
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <h1>
                    <?php if ($site): ?>
                        Components for <?php echo htmlspecialchars($site['domain']); ?>
                    <?php else: ?>
                        All Components
                    <?php endif; ?>
                </h1>
                <?php if ($site): ?>
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item"><a href="sites.php">Sites</a></li>
                            <li class="breadcrumb-item active"><?php echo htmlspecialchars($site['domain']); ?></li>
                        </ol>
                    </nav>
                <?php endif; ?>
            </div>
            <?php if (!$site): ?>
    <a href="component-create.php" class="btn btn-primary">
        <i class="fas fa-plus"></i> Create Global Component
    </a>
<?php endif; ?>
            <?php if ($site): ?>
                <a href="component-create.php?site_id=<?php echo $site['id']; ?>" class="btn btn-primary">
                    <i class="fas fa-plus"></i> Create New Component
                </a>
            <?php endif; ?>
        </div>
        
        <?php if (isset($notification)): ?>
            <div class="alert alert-<?php echo $notification['type']; ?> alert-dismissible fade show">
                <?php echo $notification['message']; ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>
        
        <?php if (isset($error)): ?>
            <div class="alert alert-danger">
                <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <!-- Filter by component type -->
        <div class="card">
            <div class="card-body">
                <div class="component-type-filter">
                    <?php 
                    $baseUrl = $site ? "?site_id={$site['id']}" : "?"; 
                    $currentUrl = $site ? "components.php?site_id={$site['id']}" : "components.php";
                    if ($componentType) {
                        $currentUrl .= "&type={$componentType}";
                    }
                    ?>
                    <a href="<?php echo $baseUrl; ?>" class="btn <?php echo !$componentType ? 'btn-primary' : 'btn-outline-primary'; ?>">
                        All Types
                    </a>
                    <a href="<?php echo $baseUrl . '&type=header'; ?>" class="btn <?php echo $componentType === 'header' ? 'btn-primary' : 'btn-outline-primary'; ?>">
                        <i class="fas fa-heading"></i> Headers
                    </a>
                    <a href="<?php echo $baseUrl . '&type=footer'; ?>" class="btn <?php echo $componentType === 'footer' ? 'btn-primary' : 'btn-outline-primary'; ?>">
                        <i class="fas fa-shoe-prints"></i> Footers
                    </a>
                    <a href="<?php echo $baseUrl . '&type=sidebar'; ?>" class="btn <?php echo $componentType === 'sidebar' ? 'btn-primary' : 'btn-outline-primary'; ?>">
                        <i class="fas fa-columns"></i> Sidebars
                    </a>
                </div>

                <?php if (!$site): ?>
                    <div class="mb-3">
                        <form action="components.php" method="get" class="d-flex">
                            <?php if ($componentType): ?>
                                <input type="hidden" name="type" value="<?php echo htmlspecialchars($componentType); ?>">
                            <?php endif; ?>
                            <select name="site_id" class="form-select me-2" onchange="this.form.submit()">
                                <option value="">-- All Sites --</option>
                                <?php 
                                $sitesStmt = $db->query("SELECT id, domain FROM sites ORDER BY domain");
                                while ($siteOption = $sitesStmt->fetch(PDO::FETCH_ASSOC)): 
                                ?>
                                    <option value="<?php echo $siteOption['id']; ?>" <?php echo $siteId == $siteOption['id'] ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($siteOption['domain']); ?>
                                    </option>
                                <?php endwhile; ?>
                            </select>
                            <button type="submit" class="btn btn-outline-primary">Filter by Site</button>
                        </form>
                    </div>
                <?php endif; ?>
            </div>
        </div>
        
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    <?php if ($componentType): ?>
                        <?php echo ucfirst(htmlspecialchars($componentType)); ?> Components (<?php echo $totalComponents; ?>)
                    <?php else: ?>
                        All Components (<?php echo $totalComponents; ?>)
                    <?php endif; ?>
                </h5>
            </div>
            
            <div class="card-body">
                <?php if (empty($components)): ?>
                    <div class="alert alert-info">
                        <?php if ($site): ?>
                            No components found for this site. Use the "Create New Component" button to add your first component.
                        <?php else: ?>
                            No components found matching your criteria.
                        <?php endif; ?>
                    </div>
                <?php else: ?>
                    <div class="table-responsive">
                        <table class="table table-striped table-hover">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <?php if (!$site): ?>
                                        <th>Site</th>
                                    <?php endif; ?>
                                    <th>Name</th>
                                    <th>Type</th>
                                    <th>Preview</th>
                                    <th>Status</th>
                                    <th>Created</th>
                                    <th>Updated</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($components as $component): ?>
                                    <tr>
                                        <td><?php echo $component['id']; ?></td>
                                        <?php if (!$site): ?>
                                            <td>
                                                <a href="components.php?site_id=<?php echo $component['site_id']; ?>">
                                                    <?php echo htmlspecialchars($component['domain']); ?>
                                                </a>
                                            </td>
                                        <?php endif; ?>
                                        <td><?php echo htmlspecialchars($component['name']); ?></td>
                                        <td>
                                            <span class="badge bg-<?php echo $component['type']; ?>">
                                                <?php echo ucfirst(htmlspecialchars($component['type'])); ?>
                                            </span>
                                        </td>
                                        <td>
                                            <div class="component-preview">
                                                <?php echo htmlspecialchars(substr($component['content'], 0, 200)); ?>...
                                            </div>
                                        </td>
                                        <td>
                                            <?php if ($component['is_active']): ?>
                                                <span class="badge bg-success">Active</span>
                                            <?php else: ?>
                                                <span class="badge bg-secondary">Inactive</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($component['created_at'])); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($component['updated_at'])); ?></td>
                                        <td>
                                            <div class="btn-group">
                                                <a href="component-edit.php?id=<?php echo $component['id']; ?>" 
                                                   class="btn btn-sm btn-primary" title="Edit">
                                                    <i class="fas fa-edit"></i>
                                                </a>
                                                

                                                
                                                <button type="button"
                                                        class="btn btn-sm btn-success preview-btn"
                                                        data-content="<?php echo htmlspecialchars($component['content']); ?>"
                                                        data-site-title="<?php echo htmlspecialchars($site ? $site['title'] : 'Example Site'); ?>"
                                                        title="Live Preview">
                                                    <i class="fas fa-desktop"></i>
                                                </button>
                                                
                                                <button type="button" 
                                                        class="btn btn-sm btn-danger delete-component" 
                                                        data-bs-toggle="modal" 
                                                        data-bs-target="#deleteModal"
                                                        data-component-id="<?php echo $component['id']; ?>"
                                                        data-component-name="<?php echo htmlspecialchars($component['name']); ?>"
                                                        title="Delete">
                                                    <i class="fas fa-trash-alt"></i>
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <?php if ($totalPages > 1): ?>
                        <nav aria-label="Page navigation" class="mt-4">
                            <ul class="pagination">
                                <li class="page-item <?php echo ($page <= 1) ? 'disabled' : ''; ?>">
                                    <a class="page-link" href="<?php echo ($page <= 1) ? '#' : $currentUrl . '&page=' . ($page - 1); ?>" aria-label="Previous">
                                        <span aria-hidden="true">&laquo;</span>
                                    </a>
                                </li>
                                
                                <?php for ($i = 1; $i <= $totalPages; $i++): ?>
                                    <li class="page-item <?php echo ($page == $i) ? 'active' : ''; ?>">
                                        <a class="page-link" href="<?php echo $currentUrl . '&page=' . $i; ?>"><?php echo $i; ?></a>
                                    </li>
                                <?php endfor; ?>
                                
                                <li class="page-item <?php echo ($page >= $totalPages) ? 'disabled' : ''; ?>">
                                    <a class="page-link" href="<?php echo ($page >= $totalPages) ? '#' : $currentUrl . '&page=' . ($page + 1); ?>" aria-label="Next">
                                        <span aria-hidden="true">&raquo;</span>
                                    </a>
                                </li>
                            </ul>
                        </nav>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <!-- View Component Modal -->
    <div class="modal fade" id="viewModal" tabindex="-1" aria-labelledby="viewModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="viewModalLabel">View Component</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <h5 id="componentName"></h5>
                    <div class="mt-3">
                        <h6>HTML Code:</h6>
                        <pre id="componentContent" class="border p-3 bg-light" style="max-height: 400px; overflow: auto;"></pre>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <a href="#" id="editComponentLink" class="btn btn-primary">Edit</a>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Delete Modal -->
    <div class="modal fade" id="deleteModal" tabindex="-1" aria-labelledby="deleteModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteModalLabel">Confirm Delete</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    Are you sure you want to delete the component <strong id="deleteComponentName"></strong>? This action cannot be undone.
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <form id="deleteForm" action="component-delete.php" method="post">
                        <input type="hidden" id="componentIdInput" name="component_id" value="">
                        <input type="hidden" id="siteIdInput" name="site_id" value="<?php echo $siteId; ?>">
                        <button type="submit" class="btn btn-danger">Delete</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
    
<!-- Preview Modal -->
<div class="preview-modal" id="previewModal">
    <div class="modal-content">
        <span class="close">&times;</span>
        <div class="preview-control-bar">
            <div class="preview-device-selector">
                <button type="button" data-device="desktop" class="device-btn active" title="Desktop View">
                    <i class="fas fa-desktop"></i>
                </button>
                <button type="button" data-device="tablet" class="device-btn" title="Tablet View">
                    <i class="fas fa-tablet-alt"></i>
                </button>
                <button type="button" data-device="mobile" class="device-btn" title="Mobile View">
                    <i class="fas fa-mobile-alt"></i>
                </button>
            </div>
            <button type="button" id="toggleVariables" title="Show/Hide Variables">
                <i class="fas fa-code"></i> <span>Variables</span>
            </button>
        </div>
        <iframe id="previewFrame" frameborder="0"></iframe>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Обработчик для кнопок предпросмотра
    const previewBtns = document.querySelectorAll('.preview-btn');
    const previewModal = document.getElementById('previewModal');
    const previewFrame = document.getElementById('previewFrame');
    const closeBtn = document.querySelector('.preview-modal .close');
    
    // Показать модальное окно при клике на кнопку предпросмотра
    previewBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // Получаем HTML-контент и заголовок сайта
            const content = this.getAttribute('data-content');
            const siteTitle = this.getAttribute('data-site-title');
            
            // Генерируем пример меню
            const demoMenu = `<ul class="nav-menu">
                <li class="active"><a href="/">Home</a></li>
                <li><a href="/about">About</a></li>
                <li><a href="/services">Services</a></li>
                <li><a href="/contact">Contact</a></li>
            </ul>`;
            
            // Заменяем переменные
            let processedContent = content
                .replace(/{site_title}/g, siteTitle)
                .replace(/{site_name}/g, siteTitle)
                .replace(/{site_url}/g, 'example.com')
                .replace(/{menu}/g, demoMenu)
                .replace(/{navigation}/g, demoMenu)
                .replace(/{current_year}/g, new Date().getFullYear());
            
            // Создаем полный HTML-документ для предпросмотра
            const componentType = this.closest('tr').querySelector('.badge').textContent.trim().toLowerCase();
            const previewHTML = `
                <!DOCTYPE html>
                <html>
                <head>
                    <meta charset="UTF-8">
                    <meta name="viewport" content="width=device-width, initial-scale=1.0">
                    <style>
                        body { font-family: Arial, sans-serif; line-height: 1.6; margin: 0; padding: 0; }
                        .container { width: 100%; max-width: 1200px; margin: 0 auto; padding: 0 15px; }
                        .site-header { background-color: #f8f9fa; padding: 1rem 0; }
                        .site-footer { background-color: #f8f9fa; padding: 1rem 0; margin-top: 2rem; }
                        .nav-menu { list-style: none; padding: 0; margin: 0; display: flex; }
                        .nav-menu li { margin-right: 1rem; }
                        .nav-menu li a { text-decoration: none; color: #333; }
                        .nav-menu li.active a { font-weight: bold; color: #007bff; }
                        
                        /* Стили для компонентов разных типов */
                        .site-header { background-color: ${componentType === 'header' ? '#e3f2fd' : '#f8f9fa'}; }
                        .site-footer { background-color: ${componentType === 'footer' ? '#e3f2fd' : '#f8f9fa'}; }
                        .sidebar { background-color: ${componentType === 'sidebar' ? '#e3f2fd' : '#f8f9fa'}; padding: 1rem; width: 250px; }
                    </style>
                </head>
                <body>
                    ${processedContent}
                </body>
                </html>
            `;
            
            // Загружаем HTML в iframe
            previewFrame.srcdoc = previewHTML;
            
            // Показываем модальное окно
            previewModal.style.display = 'block';
        });
    });
    
    // Закрыть модальное окно при клике на кнопку закрытия
    closeBtn.addEventListener('click', function() {
        previewModal.style.display = 'none';
    });
    
    // Закрыть модальное окно при клике вне его содержимого
    window.addEventListener('click', function(event) {
        if (event.target === previewModal) {
            previewModal.style.display = 'none';
        }
    });
    
    // Переключение между режимами отображения (desktop, tablet, mobile)
    const deviceBtns = document.querySelectorAll('.device-btn');
    deviceBtns.forEach(btn => {
        btn.addEventListener('click', function() {
            // Удаляем активный класс со всех кнопок
            deviceBtns.forEach(b => b.classList.remove('active'));
            // Добавляем активный класс текущей кнопке
            this.classList.add('active');
            
            // Устанавливаем ширину iframe в зависимости от выбранного устройства
            const device = this.getAttribute('data-device');
            
            if (device === 'mobile') {
                previewFrame.style.width = '375px';
            } else if (device === 'tablet') {
                previewFrame.style.width = '768px';
            } else {
                previewFrame.style.width = '100%';
            }
        });
    });
    
    // Переключение отображения переменных
    const toggleVariablesBtn = document.getElementById('toggleVariables');
    let showVariables = false;
    
    toggleVariablesBtn.addEventListener('click', function() {
        showVariables = !showVariables;
        this.classList.toggle('active', showVariables);
        
        if (showVariables) {
            // Показать переменные (заменить обратно на текстовые метки)
            const content = previewFrame.srcdoc;
            const updatedContent = content
                .replace(/Example Site/g, '{site_title}')
                .replace(/<ul class="nav-menu">[\s\S]*?<\/ul>/g, '{menu}')
                .replace(new RegExp(new Date().getFullYear(), 'g'), '{current_year}');
            
            previewFrame.srcdoc = updatedContent;
        } else {
            // Повторить последний предпросмотр, чтобы скрыть переменные
            const clickEvent = new Event('click');
            document.querySelector('.preview-btn[data-content]').dispatchEvent(clickEvent);
        }
    });
});
</script>