<?php
// admin/index.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Start session
session_start();

// Include configuration
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

// Initialize DB connection
$db = new PDO(
    "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
    DB_USER,
    DB_PASS,
    array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
);

// Initialize auth manager
$authManager = new AuthManager($db);

// Check if user is authenticated
if (!$authManager->isAuthenticated()) {
    header('Location: login.php');
    exit;
}

// Get current user
$currentUser = $authManager->getCurrentUser();

// Get sites count
$totalSitesStmt = $db->query("SELECT COUNT(*) FROM sites");
$totalSites = $totalSitesStmt->fetchColumn();

// Count active sites
$activeSitesStmt = $db->query("SELECT COUNT(*) FROM sites WHERE active = 1");
$activeSites = $activeSitesStmt->fetchColumn() ?: 0;

// Count pages
$pagesStmt = $db->query("SELECT COUNT(*) FROM pages");
$totalPages = $pagesStmt->fetchColumn() ?: 0;

// Count components
$componentsStmt = $db->query("SELECT COUNT(*) FROM components");
$totalComponents = $componentsStmt->fetchColumn() ?: 0;

// Get recent sites (if any exist)
$recentSites = [];
if ($totalSites > 0) {
    $siteStmt = $db->query("SELECT id, domain, title, active FROM sites ORDER BY created_at DESC LIMIT 5");
    $recentSites = $siteStmt->fetchAll(PDO::FETCH_ASSOC);
}

// Get recent activity logs
$logsStmt = $db->query("
    SELECT sl.*, s.domain 
    FROM system_logs sl
    LEFT JOIN sites s ON sl.site_id = s.id
    ORDER BY sl.created_at DESC 
    LIMIT 10
");
$recentLogs = $logsStmt->fetchAll(PDO::FETCH_ASSOC);

// Check for notifications
$notification = null;
if (isset($_SESSION['notification'])) {
    $notification = $_SESSION['notification'];
    unset($_SESSION['notification']);
}

$pageTitle = 'Dashboard';
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <!-- Bootstrap CSS (from CDN to avoid file issues) -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome (from CDN) -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- Custom CSS -->
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            line-height: 1.6;
            background: #f5f5f5;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background-color: #2c3e50 !important;
            padding: 0.5rem 1rem;
        }
        .navbar-brand {
            color: white !important;
            font-weight: bold;
            font-size: 1.5rem;
        }
        .nav-link {
            color: rgba(255,255,255,0.8) !important;
        }
        .nav-link:hover, .nav-link.active {
            color: white !important;
        }
        .card {
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            border: none;
            margin-bottom: 20px;
        }
        .dashboard-card {
            border-radius: 5px;
            padding: 20px;
            margin-bottom: 20px;
            color: white;
            transition: all 0.3s ease;
        }
        .dashboard-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 15px rgba(0,0,0,0.1);
        }
        .bg-primary { background-color: #3498db !important; }
        .bg-success { background-color: #2ecc71 !important; }
        .bg-warning { background-color: #f1c40f !important; }
        .bg-info { background-color: #9b59b6 !important; }
        footer {
            margin-top: 3rem;
            padding: 1.5rem 0;
            background: #f8f9fa;
            border-top: 1px solid #e9ecef;
        }
        .action-icon {
            font-size: 0.85rem;
            margin-right: 5px;
        }
        .log-item {
            border-left: 3px solid #ddd;
            padding: 8px 15px;
            margin-bottom: 8px;
            background: #f9f9f9;
        }
        .log-success { border-left-color: #2ecc71; }
        .log-error { border-left-color: #e74c3c; }
        .log-warning { border-left-color: #f39c12; }
        .log-info { border-left-color: #3498db; }
        .log-time {
            font-size: 0.8rem;
            color: #777;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="/pbns2/admin/">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link active" href="/pbns2/admin/">
                            <i class="fas fa-tachometer-alt"></i> Dashboard
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sites.php"><i class="fas fa-globe"></i> Sites</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="pages.php"><i class="fas fa-file-alt"></i> Pages</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="components.php"><i class="fas fa-puzzle-piece"></i> Components</a>
                    </li>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li>
                                <a class="dropdown-item" href="#">
                                    <i class="fas fa-user-cog"></i> Profile
                                </a>
                            </li>
                            <li><hr class="dropdown-divider"></li>
                            <li>
                                <a class="dropdown-item" href="logout.php">
                                    <i class="fas fa-sign-out-alt"></i> Logout
                                </a>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    
    <div class="container-fluid mt-4">
        <?php if (isset($notification)): ?>
            <div class="alert alert-<?php echo $notification['type']; ?> alert-dismissible fade show">
                <?php echo $notification['message']; ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>
        
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1>Dashboard</h1>
            <a href="site-create.php" class="btn btn-primary">
                <i class="fas fa-plus"></i> Create New Site
            </a>
        </div>
        
        <div class="row">
            <div class="col-md-3 mb-4">
                <a href="sites.php" class="text-decoration-none">
                    <div class="card dashboard-card bg-primary">
                        <div class="card-body">
                            <div class="d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="card-title mb-0">Total Sites</h6>
                                    <h2 class="mt-2 mb-0"><?php echo $totalSites; ?></h2>
                                </div>
                                <div>
                                    <i class="fas fa-globe fa-3x"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </a>
            </div>
            
            <div class="col-md-3 mb-4">
                <a href="sites.php?filter=active" class="text-decoration-none">
                    <div class="card dashboard-card bg-success">
                        <div class="card-body">
                            <div class="d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="card-title mb-0">Active Sites</h6>
                                    <h2 class="mt-2 mb-0"><?php echo $activeSites; ?></h2>
                                </div>
                                <div>
                                    <i class="fas fa-check-circle fa-3x"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </a>
            </div>
            
            <div class="col-md-3 mb-4">
                <a href="pages.php" class="text-decoration-none">
                    <div class="card dashboard-card bg-warning text-dark">
                        <div class="card-body">
                            <div class="d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="card-title mb-0">Total Pages</h6>
                                    <h2 class="mt-2 mb-0"><?php echo $totalPages; ?></h2>
                                </div>
                                <div>
                                    <i class="fas fa-file-alt fa-3x"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </a>
            </div>
            
            <div class="col-md-3 mb-4">
                <a href="components.php" class="text-decoration-none">
                    <div class="card dashboard-card bg-info">
                        <div class="card-body">
                            <div class="d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="card-title mb-0">Components</h6>
                                    <h2 class="mt-2 mb-0"><?php echo $totalComponents; ?></h2>
                                </div>
                                <div>
                                    <i class="fas fa-puzzle-piece fa-3x"></i>
                                </div>
                            </div>
                        </div>
                    </div>
                </a>
            </div>
        </div>
        
        <div class="row">
            <div class="col-md-8">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h5 class="mb-0">Recent Sites</h5>
                        <a href="sites.php" class="btn btn-sm btn-outline-primary">View All Sites</a>
                    </div>
                    <div class="card-body">
                        <?php if (empty($recentSites)): ?>
                            <div class="alert alert-info">
                                No sites found. Use the "Create New Site" button to add your first site.
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-striped table-hover">
                                    <thead>
                                        <tr>
                                            <th>ID</th>
                                            <th>Domain</th>
                                            <th>Title</th>
                                            <th>Status</th>
                                            <th>Actions</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($recentSites as $site): ?>
                                            <tr>
                                                <td><?php echo $site['id']; ?></td>
                                                <td>
                                                    <a href="//<?php echo htmlspecialchars($site['domain']); ?>" target="_blank">
                                                        <?php echo htmlspecialchars($site['domain']); ?>
                                                        <i class="fas fa-external-link-alt fa-xs"></i>
                                                    </a>
                                                </td>
                                                <td><?php echo htmlspecialchars($site['title']); ?></td>
                                                <td>
                                                    <?php if ($site['active']): ?>
                                                        <span class="badge bg-success">Active</span>
                                                    <?php else: ?>
                                                        <span class="badge bg-danger">Inactive</span>
                                                    <?php endif; ?>
                                                </td>
                                                <td>
                                                    <div class="btn-group">
                                                        <a href="site-edit.php?id=<?php echo $site['id']; ?>" class="btn btn-sm btn-primary" title="Edit">
                                                            <i class="fas fa-edit"></i>
                                                        </a>
                                                        <a href="pages.php?site_id=<?php echo $site['id']; ?>" class="btn btn-sm btn-info" title="Pages">
                                                            <i class="fas fa-file-alt"></i>
                                                        </a>
                                                        <a href="components.php?site_id=<?php echo $site['id']; ?>" class="btn btn-sm btn-secondary" title="Components">
                                                            <i class="fas fa-puzzle-piece"></i>
                                                        </a>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            
            <div class="col-md-4">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0">Recent Activity</h5>
                    </div>
                    <div class="card-body p-0">
                        <?php if (empty($recentLogs)): ?>
                            <div class="p-3">
                                <div class="alert alert-info mb-0">
                                    No recent activity found.
                                </div>
                            </div>
                        <?php else: ?>
                            <div class="list-group list-group-flush">
                                <?php foreach ($recentLogs as $log): ?>
                                    <div class="log-item log-<?php echo $log['status']; ?>">
                                        <div class="d-flex justify-content-between">
                                            <strong>
                                                <?php 
                                                switch($log['action']) {
                                                    case 'site_created':
                                                        echo '<i class="fas fa-plus-circle action-icon text-success"></i>';
                                                        break;
                                                    case 'page_created':
                                                        echo '<i class="fas fa-file-plus action-icon text-info"></i>';
                                                        break;
                                                    case 'site_updated':
                                                    case 'page_updated':
                                                        echo '<i class="fas fa-edit action-icon text-primary"></i>';
                                                        break;
                                                    case 'site_deleted':
                                                    case 'page_deleted':
                                                        echo '<i class="fas fa-trash-alt action-icon text-danger"></i>';
                                                        break;
                                                    default:
                                                        echo '<i class="fas fa-info-circle action-icon"></i>';
                                                }
                                                echo htmlspecialchars($log['action']);
                                                ?>
                                            </strong>
                                            <span class="log-time">
                                                <?php echo date('M d, H:i', strtotime($log['created_at'])); ?>
                                            </span>
                                        </div>
                                        <div>
                                            <?php echo htmlspecialchars($log['description']); ?>
                                        </div>
                                        <?php if ($log['domain']): ?>
                                            <small class="text-muted">
                                                Site: <?php echo htmlspecialchars($log['domain']); ?>
                                            </small>
                                        <?php endif; ?>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                
                <div class="card mt-4">
                    <div class="card-header">
                        <h5 class="mb-0">Quick Actions</h5>
                    </div>
                    <div class="card-body">
                        <div class="d-grid gap-2">
                            <a href="site-create.php" class="btn btn-primary">
                                <i class="fas fa-plus-circle"></i> Create New Site
                            </a>
                            <a href="page-create.php" class="btn btn-info text-white">
                                <i class="fas fa-file-alt"></i> Create New Page
                            </a>
                            <a href="component-create.php" class="btn btn-secondary">
                                <i class="fas fa-puzzle-piece"></i> Create New Component
                            </a>
                            <a href="backups.php" class="btn btn-success">
                                <i class="fas fa-save"></i> Manage Backups
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <footer class="text-center text-muted">
        <div class="container">
            <p class="mb-0">&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <!-- Bootstrap Bundle with Popper (from CDN) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Simple inline JS to handle dropdown without full admin.js -->
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // Enable Bootstrap dropdowns
        var dropdownElementList = [].slice.call(document.querySelectorAll('.dropdown-toggle'))
        var dropdownList = dropdownElementList.map(function (dropdownToggleEl) {
            return new bootstrap.Dropdown(dropdownToggleEl)
        });
        
        // Add click event for dashboard cards
        var dashboardCards = document.querySelectorAll('.dashboard-card');
        dashboardCards.forEach(function(card) {
            card.addEventListener('mouseenter', function() {
                this.style.cursor = 'pointer';
            });
        });
    });
    </script>
</body>
</html>