<?php
// Файл /var/www/www-root/data/www/pbnstat.ru/pbns2/admin/login.php
// Максимально простая версия без зависимостей

// Включаем отображение ошибок
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Включаем сессии
session_start();

// Опциональное подключение конфига (может быть причиной ошибки)
$configLoaded = false;
$configFile = __DIR__ . '/../config/config.php';
if (file_exists($configFile)) {
    try {
        require_once $configFile;
        $configLoaded = true;
    } catch (Exception $e) {
        $configError = $e->getMessage();
    }
}

// Переменная для ошибок
$error = '';
$dbConnection = false;

// Проверка соединения с базой данных
if ($configLoaded && defined('DB_HOST') && defined('DB_NAME') && defined('DB_USER') && defined('DB_PASS')) {
    try {
        $db = new PDO(
            "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
            DB_USER,
            DB_PASS,
            array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
        );
        $dbConnection = true;
    } catch (PDOException $e) {
        $error = "Ошибка подключения к базе данных: " . $e->getMessage();
    }
}

// Обработка формы авторизации
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $dbConnection) {
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';
    
    if (empty($username) || empty($password)) {
        $error = 'Имя пользователя и пароль обязательны';
    } else {
        try {
            // Прямая проверка учётных данных без AuthManager
            $stmt = $db->prepare("SELECT id, username, password_hash, role FROM users WHERE username = ?");
            $stmt->execute([$username]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($user && password_verify($password, $user['password_hash'])) {
                // Успешная авторизация - сохраняем в сессию
                $_SESSION['user'] = [
                    'id' => $user['id'],
                    'username' => $user['username'],
                    'role' => $user['role'],
                    'is_authenticated' => true,
                    'login_time' => time()
                ];
                
                // Обновляем время последнего входа
                $updateStmt = $db->prepare("UPDATE users SET last_login = CURRENT_TIMESTAMP WHERE id = ?");
                $updateStmt->execute([$user['id']]);
                
                // Перенаправляем на главную админки
                header('Location: index.php');
                exit;
            } else {
                $error = 'Неверное имя пользователя или пароль';
            }
        } catch (Exception $e) {
            $error = "Ошибка авторизации: " . $e->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="ru">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Вход - PBN Admin</title>
    <style>
        body { font-family: Arial, sans-serif; background: #f5f5f5; padding: 20px; }
        .login-container { max-width: 400px; margin: 50px auto; background: white; padding: 20px; border-radius: 5px; box-shadow: 0 0 10px rgba(0,0,0,0.1); }
        h1 { text-align: center; color: #333; }
        .form-group { margin-bottom: 15px; }
        label { display: block; margin-bottom: 5px; }
        input[type="text"], input[type="password"] { width: 100%; padding: 8px; box-sizing: border-box; border: 1px solid #ddd; border-radius: 4px; }
        button { width: 100%; padding: 10px; background: #4CAF50; color: white; border: none; border-radius: 4px; cursor: pointer; }
        button:hover { background: #45a049; }
        .error { color: red; margin-bottom: 15px; }
        .status { margin-top: 20px; padding: 10px; background: #f8f9fa; border-radius: 4px; font-size: 13px; }
        .success { color: green; }
    </style>
</head>
<body>
    <div class="login-container">
        <h1>PBN Admin</h1>
        <p style="text-align: center;">Упрощенная форма входа</p>
        
        <?php if (!empty($error)): ?>
            <div class="error">
                <?php echo htmlspecialchars($error); ?>
            </div>
        <?php endif; ?>
        
        <form method="post">
            <div class="form-group">
                <label for="username">Имя пользователя</label>
                <input type="text" id="username" name="username" required>
            </div>
            
            <div class="form-group">
                <label for="password">Пароль</label>
                <input type="password" id="password" name="password" required>
            </div>
            
            <button type="submit">Войти</button>
        </form>
        
        <div class="status">
            <p>Статус сессии: <?php echo session_status() === PHP_SESSION_ACTIVE ? '<span class="success">Активна</span>' : 'Неактивна'; ?></p>
            <p>Конфигурация: <?php echo $configLoaded ? '<span class="success">Загружена</span>' : 'Не загружена'; ?></p>
            <?php if (isset($configError)): ?>
                <p>Ошибка конфигурации: <?php echo htmlspecialchars($configError); ?></p>
            <?php endif; ?>
            <p>Подключение к БД: <?php echo $dbConnection ? '<span class="success">Установлено</span>' : 'Ошибка'; ?></p>
        </div>
    </div>
    
    <div style="text-align: center; margin-top: 20px; color: #666;">
        <p>&copy; <?php echo date('Y'); ?> PBN Admin</p>
    </div>
</body>
</html>