<?php
// admin/page-delete.php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Начинаем сессию
session_start();

// Подключаем конфигурацию и необходимые файлы
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../includes/SystemLogger.php';
require_once __DIR__ . '/../includes/AuthManager.php';

try {
    // Инициализируем подключение к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );

    // Инициализируем AuthManager
    $authManager = new AuthManager($db);

    // Проверяем авторизацию
    if (!$authManager->isAuthenticated()) {
        header('Location: login.php');
        exit;
    }

    // Получаем текущего пользователя
    $currentUser = $authManager->getCurrentUser();

    // Проверяем метод запроса и наличие page_id
    if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['page_id'])) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Invalid request'
        ];
        header('Location: pages.php');
        exit;
    }

    $pageId = (int)$_POST['page_id'];
    $siteId = isset($_POST['site_id']) ? (int)$_POST['site_id'] : null;

    // Получаем информацию о странице
    $pageStmt = $db->prepare("
        SELECT p.*, s.domain 
        FROM pages p
        JOIN sites s ON p.site_id = s.id 
        WHERE p.id = ?
    ");
    $pageStmt->execute([$pageId]);
    $page = $pageStmt->fetch(PDO::FETCH_ASSOC);

    if (!$page) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Page not found'
        ];
        header('Location: pages.php' . ($siteId ? "?site_id=$siteId" : ''));
        exit;
    }

    // Проверяем, является ли страница системной
    if ($page['is_system']) {
        $_SESSION['notification'] = [
            'type' => 'danger',
            'message' => 'Cannot delete system page'
        ];
        header('Location: pages.php' . ($siteId ? "?site_id=$siteId" : ''));
        exit;
    }

    // Удаляем страницу
    $deleteStmt = $db->prepare("DELETE FROM pages WHERE id = ?");
    $deleteStmt->execute([$pageId]);

    // Логируем удаление
    $logger = new SystemLogger($db);
    $logger->log(
        $page['site_id'],
        'page_deleted',
        "Page '{$page['title']}' (slug: {$page['slug']}) was deleted by {$currentUser['username']}",
        'info'
    );

    $_SESSION['notification'] = [
        'type' => 'success',
        'message' => "Page '{$page['title']}' has been successfully deleted"
    ];

    // Перенаправляем обратно на страницу со списком страниц
    header('Location: pages.php' . ($siteId ? "?site_id=$siteId" : ''));
    exit;

} catch (Exception $e) {
    error_log("Page deletion error: " . $e->getMessage());
    $_SESSION['notification'] = [
        'type' => 'danger',
        'message' => "Error deleting page: " . $e->getMessage()
    ];
    header('Location: pages.php' . (isset($siteId) ? "?site_id=$siteId" : ''));
    exit;
}