<?php
// Файл /var/www/www-root/data/www/pbnstat.ru/pbns2/admin/setup-db.php

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Проверяем существование конфига
$configFile = __DIR__ . '/../config/config.php';
if (!file_exists($configFile)) {
    die("Конфигурационный файл не найден: $configFile");
}

require_once $configFile;

try {
    // Подключаемся к базе данных
    $db = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
        DB_USER,
        DB_PASS,
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );
    
    echo "<h1>Настройка базы данных</h1>";
    
    // Проверяем существование таблицы пользователей
    $checkTable = $db->query("SHOW TABLES LIKE 'users'");
    $tableExists = $checkTable->rowCount() > 0;
    
    if (!$tableExists) {
        echo "<p>Создание таблицы пользователей...</p>";
        
        // Создаем таблицу пользователей
        $createTable = "
        CREATE TABLE users (
            id INT AUTO_INCREMENT PRIMARY KEY,
            username VARCHAR(50) NOT NULL UNIQUE,
            email VARCHAR(100) NOT NULL UNIQUE,
            password_hash VARCHAR(255) NOT NULL,
            role ENUM('administrator', 'editor', 'viewer') NOT NULL DEFAULT 'editor',
            last_login TIMESTAMP NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        
        $db->exec($createTable);
        echo "<p style='color:green'>Таблица users успешно создана</p>";
        
        // Создаем администратора по умолчанию (admin/password)
        $username = 'admin';
        $email = 'admin@example.com';
        $passwordHash = password_hash('password', PASSWORD_DEFAULT);
        $role = 'administrator';
        
        $insertAdmin = $db->prepare("
            INSERT INTO users (username, email, password_hash, role)
            VALUES (?, ?, ?, ?)
        ");
        
        $insertAdmin->execute([$username, $email, $passwordHash, $role]);
        echo "<p style='color:green'>Пользователь admin создан</p>";
    } else {
        echo "<p>Таблица users уже существует</p>";
        
        // Проверяем наличие администратора
        $checkAdmin = $db->query("SELECT id FROM users WHERE role = 'administrator'");
        if ($checkAdmin->rowCount() === 0) {
            // Создаем администратора, если его нет
            $username = 'admin';
            $email = 'admin@example.com';
            $passwordHash = password_hash('password', PASSWORD_DEFAULT);
            $role = 'administrator';
            
            $insertAdmin = $db->prepare("
                INSERT INTO users (username, email, password_hash, role)
                VALUES (?, ?, ?, ?)
            ");
            
            $insertAdmin->execute([$username, $email, $passwordHash, $role]);
            echo "<p style='color:green'>Пользователь admin создан</p>";
        } else {
            echo "<p>Администратор уже существует в системе</p>";
        }
    }
    
    // Выводим список пользователей
    echo "<h2>Список пользователей:</h2>";
    $users = $db->query("SELECT id, username, email, role, created_at FROM users");
    
    if ($users->rowCount() > 0) {
        echo "<table border='1' cellpadding='5'>";
        echo "<tr><th>ID</th><th>Имя пользователя</th><th>Email</th><th>Роль</th><th>Дата создания</th></tr>";
        
        while ($user = $users->fetch(PDO::FETCH_ASSOC)) {
            echo "<tr>";
            echo "<td>{$user['id']}</td>";
            echo "<td>{$user['username']}</td>";
            echo "<td>{$user['email']}</td>";
            echo "<td>{$user['role']}</td>";
            echo "<td>{$user['created_at']}</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p>Пользователи не найдены</p>";
    }
    
} catch (PDOException $e) {
    die("Ошибка базы данных: " . $e->getMessage());
}