<?php
// admin/templates/layout.php

// Start session
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Include configuration
require_once __DIR__ . '/../../config/config.php';

// Include auth manager
require_once __DIR__ . '/../../includes/AuthManager.php';

// Initialize DB connection
$db = new PDO(
    "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME,
    DB_USER,
    DB_PASS,
    array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
);

// Initialize auth manager
$authManager = new AuthManager($db);

// Check if user is authenticated
if (!$authManager->isAuthenticated() && basename($_SERVER['PHP_SELF']) !== 'login.php') {
    header('Location: login.php');
    exit;
}

// Get current user
$currentUser = $authManager->getCurrentUser();

// Define page title
$pageTitle = $pageTitle ?? 'PBN Admin';

// Get notifications
$notifications = [];
if (isset($_SESSION['notifications'])) {
    $notifications = $_SESSION['notifications'];
    unset($_SESSION['notifications']);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - PBN Admin</title>
    <link rel="stylesheet" href="assets/css/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/fontawesome.min.css">
    <link rel="stylesheet" href="assets/css/admin.css">
    <script src="assets/js/jquery.min.js"></script>
    <script src="assets/js/bootstrap.bundle.min.js"></script>
</head>
<body>
    <?php if ($authManager->isAuthenticated()): ?>
    <nav class="navbar navbar-expand-lg navbar-dark bg-primary">
        <div class="container-fluid">
            <a class="navbar-brand" href="index.php">PBN Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" href="index.php"><i class="fas fa-tachometer-alt"></i> Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="sites.php"><i class="fas fa-globe"></i> Sites</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="pages.php"><i class="fas fa-file-alt"></i> Pages</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="components.php"><i class="fas fa-puzzle-piece"></i> Components</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="media.php"><i class="fas fa-images"></i> Media</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="redirects.php"><i class="fas fa-exchange-alt"></i> Redirects</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="settings.php"><i class="fas fa-cogs"></i> Settings</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="backups.php"><i class="fas fa-save"></i> Backups</a>
                    </li>
                    <?php if ($authManager->hasRole('administrator')): ?>
                    <li class="nav-item">
                        <a class="nav-link" href="users.php"><i class="fas fa-users"></i> Users</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="logs.php"><i class="fas fa-history"></i> Logs</a>
                    </li>
                    <?php endif; ?>
                </ul>
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="userDropdown" role="button" data-bs-toggle="dropdown">
                            <i class="fas fa-user"></i> <?php echo htmlspecialchars($currentUser['username']); ?>
                        </a>
                        <div class="dropdown-menu dropdown-menu-end">
                            <a class="dropdown-item" href="profile.php">
                                <i class="fas fa-user-cog"></i> Profile
                            </a>
                            <div class="dropdown-divider"></div>
                            <a class="dropdown-item" href="logout.php">
                                <i class="fas fa-sign-out-alt"></i> Logout
                            </a>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
    <?php endif; ?>
    
    <div class="container-fluid mt-4">
        <?php if (!empty($notifications)): ?>
            <?php foreach ($notifications as $notification): ?>
                <div class="alert alert-<?php echo $notification['type']; ?> alert-dismissible fade show">
                    <?php echo $notification['message']; ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
        
        <?php if (!empty($pageTitle)): ?>
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h1><?php echo $pageTitle; ?></h1>
            <?php if (!empty($pageButtons)): ?>
                <div class="page-buttons">
                    <?php echo $pageButtons; ?>
                </div>
            <?php endif; ?>
        </div>
        <?php endif; ?>
        
        <div class="content">
            <?php include $contentTemplate; ?>
        </div>
    </div>
    
    <footer class="mt-5 p-3 text-center text-muted">
        <div class="container">
            <p>&copy; <?php echo date('Y'); ?> PBN Admin. All rights reserved.</p>
        </div>
    </footer>
    
    <script src="assets/js/admin.js"></script>
</body>
</html>