<?php
// admin/templates/page-form.php
?>
<div class="card">
    <div class="card-body">
        <?php if (!empty($error)): ?>
            <div class="alert alert-danger">
                <?php echo htmlspecialchars($error); ?>
            </div>
        <?php endif; ?>
        
        <form method="post" action="<?php echo htmlspecialchars($_SERVER['PHP_SELF'] . 
            "?site_id={$siteId}" . ($pageId ? "&id={$pageId}" : '')); ?>">
            
            <div class="row mb-3">
                <div class="col-md-6">
                    <label for="title" class="form-label">Page Title *</label>
                    <input type="text" class="form-control" id="title" name="title" 
                           value="<?php echo htmlspecialchars($page['title'] ?? ''); ?>" required>
                </div>
                
                <div class="col-md-6">
                    <label for="slug" class="form-label">URL Slug *</label>
                    <input type="text" class="form-control" id="slug" name="slug" 
                           value="<?php echo htmlspecialchars($page['slug'] ?? ''); ?>" required
                           <?php echo ($page && $page['is_system']) ? 'readonly' : ''; ?>>
                    <div class="form-text">URL: <?php echo htmlspecialchars($site['domain']); ?>/
                        <span id="slug-preview"><?php echo htmlspecialchars($page['slug'] ?? ''); ?></span>
                    </div>
                </div>
            </div>
            
            <div class="mb-3">
                <label for="h1" class="form-label">Main Heading (H1)</label>
                <input type="text" class="form-control" id="h1" name="h1" 
                       value="<?php echo htmlspecialchars($page['h1'] ?? ''); ?>">
                <div class="form-text">If left empty, the page title will be used</div>
            </div>
            
            <div class="mb-3">
                <label for="content" class="form-label">Page Content</label>
                <textarea class="form-control wysiwyg-editor" id="content" name="content" rows="15"><?php echo htmlspecialchars($page['content'] ?? ''); ?></textarea>
            </div>
            
            <h5 class="mt-4">SEO Settings</h5>
            <hr>
            
            <div class="row mb-3">
                <div class="col-12">
                    <label for="meta_title" class="form-label">Meta Title</label>
                    <input type="text" class="form-control" id="meta_title" name="meta_title" 
                           value="<?php echo htmlspecialchars($page['meta_title'] ?? ''); ?>">
                    <div class="form-text">If left empty, the page title will be used</div>
                </div>
            </div>
            
            <div class="mb-3">
                <label for="meta_description" class="form-label">Meta Description</label>
                <textarea class="form-control" id="meta_description" name="meta_description" rows="3"><?php echo htmlspecialchars($page['meta_description'] ?? ''); ?></textarea>
            </div>
            
            <div class="mb-3">
                <div class="form-check">
                    <input type="checkbox" class="form-check-input" id="is_system" name="is_system" 
                           <?php echo (isset($page) && $page['is_system']) ? 'checked' : ''; ?>
                           <?php echo (isset($page) && $page['is_system']) ? 'disabled' : ''; ?>>
                    <label class="form-check-label" for="is_system">System Page</label>
                    <div class="form-text">System pages cannot be deleted (e.g., home, 404)</div>
                </div>
            </div>
            
            <div class="d-flex justify-content-between">
                <a href="pages.php?site_id=<?php echo $siteId; ?>" class="btn btn-secondary">Cancel</a>
                <button type="submit" class="btn btn-primary">
                    <?php echo $pageId ? 'Update Page' : 'Create Page'; ?>
                </button>
            </div>
        </form>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Initialize WYSIWYG editor
    if (document.querySelector('.wysiwyg-editor')) {
        ClassicEditor
            .create(document.querySelector('.wysiwyg-editor'), {
                toolbar: ['heading', '|', 'bold', 'italic', 'link', 'bulletedList', 'numberedList', 'blockQuote', 'insertTable', 'undo', 'redo']
            })
            .catch(error => {
                console.error(error);
            });
    }
    
    // Slug generator
    const titleInput = document.getElementById('title');
    const slugInput = document.getElementById('slug');
    const slugPreview = document.getElementById('slug-preview');
    
    if (titleInput && slugInput && !slugInput.readOnly) {
        titleInput.addEventListener('input', function() {
            const slug = this.value
                .toLowerCase()
                .replace(/[^a-z0-9]+/g, '-')
                .replace(/-+/g, '-')
                .replace(/^-|-$/g, '');
            
            slugInput.value = slug;
            if (slugPreview) {
                slugPreview.textContent = slug;
            }
        });
        
        slugInput.addEventListener('input', function() {
            if (slugPreview) {
                slugPreview.textContent = this.value;
            }
        });
    }
});
</script>