<?php
// admin/templates/site-form.php
?>
<div class="card">
   <div class="card-body">
       <?php if (!empty($error)): ?>
           <div class="alert alert-danger">
               <?php echo htmlspecialchars($error); ?>
           </div>
       <?php endif; ?>
       
       <form method="post" action="<?php echo htmlspecialchars($_SERVER['PHP_SELF'] . ($siteId ? "?id={$siteId}" : '')); ?>">
           <div class="row mb-3">
               <div class="col-md-6">
                   <label for="domain" class="form-label">Domain *</label>
                   <input type="text" class="form-control" id="domain" name="domain" 
                          value="<?php echo htmlspecialchars($site['domain'] ?? ''); ?>" required
                          <?php echo $siteId ? 'readonly' : ''; ?>>
                   <div class="form-text">Enter domain without http/https (e.g., example.com)</div>
               </div>
               
               <div class="col-md-6">
                   <label for="title" class="form-label">Site Title *</label>
                   <input type="text" class="form-control" id="title" name="title" 
                          value="<?php echo htmlspecialchars($site['title'] ?? ''); ?>" required>
               </div>
           </div>
           
           <div class="row mb-3">
               <div class="col-md-4">
                   <div class="form-check">
                       <input type="checkbox" class="form-check-input" id="active" name="active" 
                              <?php echo (isset($site) && $site['active']) || !isset($site) ? 'checked' : ''; ?>>
                       <label class="form-check-label" for="active">Site Active</label>
                   </div>
               </div>
               
               <div class="col-md-4">
                   <div class="form-check">
                       <input type="checkbox" class="form-check-input" id="ssl_enabled" name="ssl_enabled" 
                              <?php echo (isset($site) && $site['ssl_enabled']) || !isset($site) ? 'checked' : ''; ?>>
                       <label class="form-check-label" for="ssl_enabled">Enable SSL</label>
                   </div>
               </div>
               
               <div class="col-md-4">
                   <div class="form-check">
                       <input type="checkbox" class="form-check-input" id="cloudflare_enabled" name="cloudflare_enabled" 
                              <?php echo (isset($site) && $site['cloudflare_enabled']) || !isset($site) ? 'checked' : ''; ?>>
                       <label class="form-check-label" for="cloudflare_enabled">Enable CloudFlare</label>
                   </div>
               </div>
           </div>
           
           <div class="d-flex justify-content-between">
               <a href="sites.php" class="btn btn-secondary">Cancel</a>
               <button type="submit" class="btn btn-primary">
                   <?php echo $siteId ? 'Update Site' : 'Create Site'; ?>
               </button>
           </div>
       </form>
   </div>
</div>

<?php if ($siteId): ?>
<div class="card mt-4">
   <div class="card-header">
       <h5>Advanced Options</h5>
   </div>
   <div class="card-body">
       <div class="row">
           <div class="col-md-6">
               <h6>Regenerate Apache Configuration</h6>
               <p>Use this option if you need to recreate the Apache configuration for this site.</p>
               <form method="post" action="regenerate-apache.php">
                   <input type="hidden" name="site_id" value="<?php echo $siteId; ?>">
                   <button type="submit" class="btn btn-warning" 
                           onclick="return confirm('Are you sure you want to regenerate Apache configuration?');">
                       <i class="fas fa-sync-alt"></i> Regenerate Apache Config
                   </button>
               </form>
           </div>
           
           <div class="col-md-6">
               <h6>Reset CloudFlare Settings</h6>
               <p>This will update or reset the CloudFlare integration for this domain.</p>
               <form method="post" action="reset-cloudflare.php">
                   <input type="hidden" name="site_id" value="<?php echo $siteId; ?>">
                   <button type="submit" class="btn btn-info" 
                           onclick="return confirm('Are you sure you want to reset CloudFlare settings?');">
                       <i class="fas fa-cloud"></i> Reset CloudFlare
                   </button>
               </form>
           </div>
       </div>
   </div>
</div>
<?php endif; ?>