<?php
// create_tables.php
error_reporting(E_ALL);
ini_set('display_errors', 1);

try {
    $db = new PDO(
        "mysql:host=localhost;dbname=multisite2",
        "multisite2",
        "gR1iA1aE9m",
        array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION)
    );
    
    // Создание таблиц
    $queries = [
        // Таблица сайтов
        "CREATE TABLE IF NOT EXISTS sites (
            id INT AUTO_INCREMENT PRIMARY KEY,
            domain VARCHAR(255) NOT NULL UNIQUE,
            title VARCHAR(255) NOT NULL,
            active BOOLEAN DEFAULT true,
            ssl_enabled BOOLEAN DEFAULT true,
            cloudflare_enabled BOOLEAN DEFAULT true,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )",
        
        // Таблица страниц
        "CREATE TABLE IF NOT EXISTS pages (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT NOT NULL,
            title VARCHAR(255) NOT NULL,
            slug VARCHAR(255) NOT NULL,
            content TEXT,
            h1 VARCHAR(255),
            meta_title VARCHAR(255),
            meta_description TEXT,
            is_system BOOLEAN DEFAULT false,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id),
            UNIQUE KEY unique_page_per_site (site_id, slug)
        )",
        
        // Таблица компонентов
        "CREATE TABLE IF NOT EXISTS components (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT NOT NULL,
            name VARCHAR(255) NOT NULL,
            type ENUM('header', 'footer', 'sidebar') NOT NULL,
            content TEXT,
            is_active BOOLEAN DEFAULT true,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id)
        )",
        
        // Таблица настроек сайтов
        "CREATE TABLE IF NOT EXISTS site_settings (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT NOT NULL,
            key_name VARCHAR(255) NOT NULL,
            value TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id),
            UNIQUE KEY unique_setting_per_site (site_id, key_name)
        )",
        
        // Таблица редиректов
        "CREATE TABLE IF NOT EXISTS redirects (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT NOT NULL,
            source_url VARCHAR(255) NOT NULL,
            target_url VARCHAR(255) NOT NULL,
            redirect_type ENUM('301', '302') DEFAULT '301',
            is_active BOOLEAN DEFAULT true,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id)
        )",
        
        // Таблица для логов системы
        "CREATE TABLE IF NOT EXISTS system_logs (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT,
            action VARCHAR(255) NOT NULL,
            description TEXT,
            status ENUM('success', 'error', 'warning') NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id)
        )",
        
        // Таблица пользователей
        "CREATE TABLE IF NOT EXISTS users (
            id INT AUTO_INCREMENT PRIMARY KEY,
            username VARCHAR(50) NOT NULL UNIQUE,
            email VARCHAR(100) NOT NULL UNIQUE,
            password_hash VARCHAR(255) NOT NULL,
            role ENUM('administrator', 'editor', 'viewer') DEFAULT 'editor',
            last_login TIMESTAMP NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
        )",
        
        // Таблица для медиафайлов
        "CREATE TABLE IF NOT EXISTS media (
            id INT AUTO_INCREMENT PRIMARY KEY,
            site_id INT NOT NULL,
            filename VARCHAR(255) NOT NULL,
            original_name VARCHAR(255) NOT NULL,
            file_path VARCHAR(255) NOT NULL,
            file_type VARCHAR(100) NOT NULL,
            file_size INT NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (site_id) REFERENCES sites(id)
        )"
    ];
    
    foreach ($queries as $query) {
        $db->exec($query);
        echo "SQL выполнен успешно: " . substr($query, 0, 50) . "...<br>";
    }
    
    // Создание администратора по умолчанию
    $adminExists = $db->query("SELECT id FROM users WHERE username = 'admin'")->fetchColumn();
    
    if (!$adminExists) {
        $password_hash = password_hash('admin123', PASSWORD_DEFAULT);
        $query = "INSERT INTO users (username, email, password_hash, role) 
                  VALUES ('admin', 'admin@example.com', '$password_hash', 'administrator')";
        $db->exec($query);
        echo "Создан пользователь по умолчанию: admin / admin123<br>";
    }
    
    echo "<h3>Все таблицы успешно созданы!</h3>";
    
} catch(PDOException $e) {
    echo "Ошибка: " . $e->getMessage();
}
?>